CliReadLine typedef
CliReadLine =
String? Function()
Signature used to read a single line from the terminal.
Implementation
typedef CliReadLine = String? Function();
Signature used to read a single line from the terminal.
typedef CliReadLine = String? Function();