ClientGeneratorOptions class

Provider-agnostic customization points used when generating ComonOrm.

Constructors

ClientGeneratorOptions({List<String> additionalImports = const <String>[], List<String> additionalClassMembers = const <String>[], List<String> additionalDeclarations = const <String>[], bool emitDefaultMigrateMethod = true})
Creates generator options.
const

Properties

additionalClassMembers List<String>
Extra class members supplied by provider-specific tooling.
final
additionalDeclarations List<String>
Extra declarations supplied by provider-specific tooling.
final
additionalImports List<String>
Extra imports supplied by provider-specific tooling.
final
emitDefaultMigrateMethod bool
Whether the generator should emit the generic adapter-based migrate().
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited