CodeConstructor class

A constructor declaration for a class.

Annotations
  • @immutable

Constructors

CodeConstructor({required String className, List<CodeParameter> parameters = const <CodeParameter>[], bool isConst = true, List<String> bodyLines = const <String>[]})
Creates a constructor node.
const

Properties

bodyLines List<String>
Raw body source lines (empty means no body, just ;).
final
className String
Class name used in the constructor declaration.
final
hashCode int
The hash code for this object.
no setterinherited
isConst bool
Whether the constructor is declared const.
final
parameters List<CodeParameter>
Parameter list.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited