GeneratedClientSchemaMismatchException class

Thrown when a checked-in/generated client was produced from a different schema than the current one.

Implemented types

Constructors

GeneratedClientSchemaMismatchException({required String outputPath, required String diff})
Creates a schema-mismatch error for a stale generated client file.
const

Properties

diff String
Human-readable schema diff between the embedded and current schema.
final
hashCode int
The hash code for this object.
no setterinherited
outputPath String
Absolute path to the generated client file that no longer matches.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited