GeneratedClientWriteResult class

Result of writing generated client code to disk.

Constructors

GeneratedClientWriteResult({required String outputPath, required bool updated})
Creates a write result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
outputPath String
Absolute path to the generated client file.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updated bool
Whether the file content changed on disk.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited