GeneratorDefinition class

Parsed generator block.

Annotations
  • @immutable

Constructors

GeneratorDefinition({required String name, required Map<String, String> properties, int? line, int? column})
Creates a generator definition.
const

Properties

column int?
One-based source column where the generator block starts, if known.
final
hashCode int
The hash code for this object.
no setterinherited
line int?
One-based source line where the generator block starts, if known.
final
name String
Generator block name.
final
properties Map<String, String>
Raw generator properties keyed by property name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited