relationName property
String
get
relationName
Stable relation name used in migration and introspection flows.
Implementation
String get relationName => tableName;
Stable relation name used in migration and introspection flows.
String get relationName => tableName;