LoadedSchemaDocument class

Validated schema together with its source file path.

Constructors

LoadedSchemaDocument({required String filePath, required SchemaDocument schema})
Creates a loaded schema document.
const

Properties

filePath String
Absolute or logical schema file path.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema SchemaDocument
Parsed and validated schema document.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited