ModelAttribute class

Parsed model-level attribute.

Annotations
  • @immutable

Constructors

ModelAttribute({required String name, required Map<String, String> arguments, int? line, int? column})
Creates a model attribute.
const

Properties

arguments Map<String, String>
Parsed attribute arguments keyed by argument name.
final
column int?
One-based source column where the attribute appears, if known.
final
hashCode int
The hash code for this object.
no setterinherited
line int?
One-based source line where the attribute appears, if known.
final
name String
Attribute name without the @@ prefix.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited