NativeTypeRule class

Validation rule describing how one provider native type can be used.

Constructors

NativeTypeRule({required Set<String> allowedScalars, bool allowsEnum = false, NativeTypeArgumentRule argumentRule = NativeTypeArgumentRule.none})
Creates a normalized native-type validation rule.
const

Properties

allowedScalars Set<String>
Scalar field types accepted by this native type.
final
allowsEnum bool
Whether the native type also accepts enum fields.
final
argumentRule NativeTypeArgumentRule
Additional argument validation rule for the native type.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedFieldDescription String
Human-readable description of the field kinds supported by the rule.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited