ParsedImplicitManyToManyTableName class

Parsed components extracted from an implicit many-to-many table name.

Annotations
  • @immutable

Constructors

ParsedImplicitManyToManyTableName({required String firstModelName, required String firstFieldName, required String secondModelName, required String secondFieldName})
Creates a parsed implicit relation table name.
const

Properties

firstFieldName String
Relation field encoded on the first side of the storage table.
final
firstModelName String
Model name encoded on the first side of the storage table.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondFieldName String
Relation field encoded on the second side of the storage table.
final
secondModelName String
Model name encoded on the second side of the storage table.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited