ProviderCodegenSnippet class

Provider-emitted code fragments consumed by the core generator.

Constructors

ProviderCodegenSnippet({required List<String> imports, required String staticMethods, required String topLevelCode, bool emitDefaultMigrateMethod = false})
Creates a provider codegen snippet payload.
const
ProviderCodegenSnippet.fromJson(Map<String, Object?> json)
Decodes a provider snippet from the provider CLI JSON payload.
factory

Properties

emitDefaultMigrateMethod bool
Whether the core generator should also emit the generic migrate().
final
hashCode int
The hash code for this object.
no setterinherited
imports List<String>
Import lines that should be merged into the generated client.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staticMethods String
Static helper methods to inject into the generated ComonOrm class.
final
topLevelCode String
Additional top-level declarations emitted by the provider.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited