emitDefaultMigrateMethod property
Whether the core generator should also emit the generic migrate().
Implementation
final bool emitDefaultMigrateMethod;
Whether the core generator should also emit the generic migrate().
final bool emitDefaultMigrateMethod;