SchemaParseException class

Error thrown when schema.prisma source cannot be parsed.

Implemented types

Constructors

SchemaParseException(String message, {int? line, int? column})
Creates a parse exception.
const

Properties

column int?
One-based column number where parsing failed, if known.
final
hashCode int
The hash code for this object.
no setterinherited
line int?
One-based line number where parsing failed, if known.
final
message String
Human-readable parse error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited