SchemaParseResult class

Result of a tolerant parse via SchemaParser.parseResult.

Constructors

SchemaParseResult({required SchemaDocument document, required List<SchemaParseError> errors})
Creates a parse result.
const

Properties

document SchemaDocument
Partially or fully constructed schema document.
final
errors List<SchemaParseError>
All parse errors collected during parsing.
final
hasErrors bool
true when at least one error was recorded.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited