SchemaValidator class

Validates parsed schema documents against the supported feature set.

Constructors

SchemaValidator()
Creates a stateless validator.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(SchemaDocument schema, {Map<String, Map<String, NativeTypeRule>> nativeTypeRulesByProvider = const <String, Map<String, NativeTypeRule>>{}}) List<ValidationIssue>
Returns validation issues for schema.

Operators

operator ==(Object other) bool
The equality operator.
inherited