Token class

A single lexer token with source position.

Constructors

Token(TokenKind kind, String value, int line, int column)
Creates a token.
const

Properties

column int
One-based source column (character offset within the line).
final
hashCode int
The hash code for this object.
no setterinherited
kind TokenKind
Token category.
final
line int
One-based source line.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Raw source text of the token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited