ValidationIssue class

Validation issue emitted by the schema validator.

Annotations
  • @immutable

Constructors

ValidationIssue({required String message, String? modelName, String? fieldName, String? filePath, int? line, int? column})
Creates a validation issue.
const

Properties

column int?
One-based source column associated with the issue, if any.
final
fieldName String?
Field name associated with the issue, if any.
final
filePath String?
Source file path associated with the issue, if any.
final
hashCode int
The hash code for this object.
no setterinherited
line int?
One-based source line associated with the issue, if any.
final
message String
Human-readable issue message.
final
modelName String?
Model name associated with the issue, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited