CountQuery class

Query object for counting records.

Annotations
  • @immutable

Constructors

CountQuery({required String model, List<QueryPredicate> where = const <QueryPredicate>[]})
Creates a count query.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
model String
Model name to query.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
where List<QueryPredicate>
Predicates used to restrict the count.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited