rawExecute abstract method

Future<int> rawExecute(
  1. String sql, [
  2. List<Object?> parameters = const <Object?>[]
])

Executes a raw SQL statement and returns the number of affected rows.

sql must use the adapter's native parameter placeholder syntax and parameters must be passed separately — never interpolate user data directly into the SQL string.

Implementation

Future<int> rawExecute(
  String sql, [
  List<Object?> parameters = const <Object?>[],
]);