Hook surface for observing or mutating adapter operations.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
afterQuery(
DatabaseMiddlewareResult result) → FutureOr< void> - Runs after the wrapped adapter operation completes or throws.
-
beforeQuery(
DatabaseMiddlewareContext context) → FutureOr< void> - Runs before the wrapped adapter operation executes.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited