GeneratedDatasourceMetadata class

Generated datasource metadata for runtime bootstrap.

Annotations
  • @immutable

Constructors

GeneratedDatasourceMetadata({required String name, required String provider, required GeneratedDatasourceUrl url})
Creates generated datasource metadata.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Datasource block name.
final
provider String
Datasource provider such as postgresql or sqlite.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url GeneratedDatasourceUrl
URL source description for runtime resolution.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited