GeneratedDatasourceUrlKind enum

Parser-independent URL source kinds for generated datasource metadata.

Inheritance
Available extensions

Values

literal → const GeneratedDatasourceUrlKind

URL is embedded directly in generated metadata.

env → const GeneratedDatasourceUrlKind

URL is resolved from an environment variable.

expression → const GeneratedDatasourceUrlKind

URL expression exists but is not yet classified more specifically.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GeneratedDatasourceUrlKind>
A constant List of the values in this enum, in order of their declaration.