GeneratedEnumMetadata class

Generated enum metadata for runtime lookup and normalization.

Annotations
  • @immutable

Constructors

GeneratedEnumMetadata({required String name, required String databaseName, required List<String> values})
Creates generated enum metadata.
const

Properties

databaseName String
Mapped database enum type name.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Logical enum name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
Enum values in declaration order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited