GeneratedRelationMetadata class

Generated relation metadata attached to a relation field.

Annotations
  • @immutable

Constructors

GeneratedRelationMetadata({required String targetModel, required GeneratedRuntimeRelationCardinality cardinality, required GeneratedRuntimeRelationStorageKind storageKind, required List<String> localFields, required List<String> targetFields, String? relationName, String? inverseField, String? storageTableName, List<String> sourceJoinColumns = const <String>[], List<String> targetJoinColumns = const <String>[]})
Creates generated relation metadata.
const

Properties

cardinality GeneratedRuntimeRelationCardinality
Relation cardinality from the source field point of view.
final
hashCode int
The hash code for this object.
no setterinherited
inverseField String?
Optional inverse field name on the target model.
final
localFields List<String>
Source-side local fields used to resolve the relation.
final
relationName String?
Optional relation name for explicit or disambiguated relations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceJoinColumns List<String>
Source-side join columns for implicit many-to-many storage.
final
storageKind GeneratedRuntimeRelationStorageKind
Storage strategy used by the relation.
final
storageTableName String?
Join table name for implicit many-to-many relations.
final
targetFields List<String>
Target-side referenced fields.
final
targetJoinColumns List<String>
Target-side join columns for implicit many-to-many storage.
final
targetModel String
Related model name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited