RuntimeDatasourceView class abstract interface

Runtime datasource bridge.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Datasource name.
no setter
provider String
Datasource provider.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url RuntimeDatasourceUrlView
Datasource URL view.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited