SchemaParser class

Parses Prisma-inspired schema source into a SchemaDocument.

The parser is built on SchemaLexer and uses a recursive descent approach. Two entry points are provided:

Constructors

SchemaParser()
Creates a stateless parser.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String source) SchemaDocument
Parses raw schema source and returns a SchemaDocument.
parseResult(String source) SchemaParseResult
Parses raw schema source tolerantly.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited