DeployResult class

Result of applying all pending local migrations.

Constructors

DeployResult({required int localMigrationCount, required List<String> appliedMigrationNames})
Creates a deploy result.
const

Properties

appliedAny bool
Whether any migrations were applied.
no setter
appliedMigrationNames List<String>
Migration names applied during deployment.
final
hashCode int
The hash code for this object.
no setterinherited
localMigrationCount int
Number of local migration directories discovered on disk.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited