MigrationResult<TPlan extends PlannedMigration> class

Result of applying a relational migration plan.

Constructors

MigrationResult({required TPlan plan, required bool applied})
Creates a migration result.
const

Properties

applied bool
Whether the migration was applied.
final
hashCode int
The hash code for this object.
no setterinherited
plan → TPlan
Executed or proposed migration plan.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited