isClean property
bool
get
isClean
Whether the local artifacts and database history are in sync.
Implementation
bool get isClean => issues.isEmpty;
Whether the local artifacts and database history are in sync.
bool get isClean => issues.isEmpty;