MigrationStatusIssue class

Issue reported when local and database migration state differ.

Constructors

MigrationStatusIssue({required String code, required String message})
Creates a status issue.
const

Properties

code String
Stable machine-readable issue code.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable issue description.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited