PlannedMigration class abstract interface

Contract implemented by relational migration plans.

Properties

hashCode int
The hash code for this object.
no setterinherited
requiresRebuild bool
Whether the change requires a schema rebuild.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statements List<String>
SQL statements that can be applied directly.
no setter
warnings List<String>
Human-readable warnings that require operator review.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited