ClientGenerator class
Generates a typed Dart client from a validated schema AST.
Constructors
- ClientGenerator({ClientGeneratorOptions options = const ClientGeneratorOptions()})
-
Creates a stateless generator.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → ClientGeneratorOptions
-
Generator configuration that affects emitted helper surfaces.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateClient(
SchemaDocument schema, {String? schemaSource}) → String -
Returns the generated client source for
schema. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited