CodeClass class
A full Dart class declaration.
- Annotations
-
- @immutable
Constructors
-
CodeClass({required String name, List<
CodeField> fields = const <CodeField>[], List<CodeConstructor> constructors = const <CodeConstructor>[], List<CodeMethod> methods = const <CodeMethod>[]}) -
Creates a class node.
const
Properties
-
constructors
→ List<
CodeConstructor> -
Constructor declarations.
final
-
fields
→ List<
CodeField> -
Field declarations (in order of appearance).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ List<
CodeMethod> -
Method declarations.
final
- name → String
-
Class name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited