CodeParameter class
A constructor parameter, either positional or named.
- Annotations
-
- @immutable
Constructors
Properties
- defaultValue → String?
-
Default value literal, e.g.
'false','null'.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isNamed → bool
-
Whether the parameter is a named parameter (
{name}).final - isThis → bool
-
Whether the parameter uses the
this.initializer shorthand.final - name → String
-
Parameter name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String?
-
Explicit Dart type string; omitted when isThis is true.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited