CodeRenderer class
Renders CodeClass IR nodes to Dart source strings.
The default two-space indentation matches the rest of the generated client.
Constructors
- CodeRenderer({String indent = ' '})
-
Creates a renderer.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renderClass(
CodeClass cls) → String -
Renders
clsto a Dart class declaration string ending with a blank line. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited