GeneratedClientWriter class
Writes generated client output for a loaded schema.
Constructors
- GeneratedClientWriter({SchemaWorkflow workflow = const SchemaWorkflow()})
-
Creates a writer with configurable schema workflow.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workflow → SchemaWorkflow
-
Workflow used to resolve generator configuration.
final
Methods
-
ensureMatchesLoadedSchemaSync(
LoadedSchemaDocument loaded, {String? generatorName, String? outputPath}) → void -
Verifies that an existing generated client matches
loaded. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeForLoadedSchema(
LoadedSchemaDocument loaded, {String? generatorName, String? outputPath}) → Future< GeneratedClientWriteResult> -
Generates and writes client code for
loaded. -
writeForLoadedSchemaSync(
LoadedSchemaDocument loaded, {String? generatorName, String? outputPath}) → GeneratedClientWriteResult -
Synchronously generates and writes client code for
loaded.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited