ImplicitManyToManyStorageDefinition class
Resolved storage mapping for an implicit many-to-many relation.
- Annotations
-
- @immutable
Constructors
-
ImplicitManyToManyStorageDefinition({required String tableName, required ModelDefinition sourceModel, required FieldDefinition sourceField, required List<
String> sourceKeyFields, required List<String> sourceJoinColumns, required ModelDefinition targetModel, required FieldDefinition targetField, required List<String> targetKeyFields, required List<String> targetJoinColumns}) -
Creates a resolved implicit relation storage description.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- relationName → String
-
Stable relation name used in migration and introspection flows.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
Stable identifier that captures both sides of the storage mapping.
no setter
- sourceField → FieldDefinition
-
Source-side relation field.
final
-
sourceJoinColumns
→ List<
String> -
Source-side join columns stored in tableName.
final
-
sourceKeyFields
→ List<
String> -
Source-side primary key fields used in the join table.
final
- sourceModel → ModelDefinition
-
Source-side model definition.
final
- tableName → String
-
Join table name.
final
- targetField → FieldDefinition
-
Target-side relation field.
final
-
targetJoinColumns
→ List<
String> -
Target-side join columns stored in tableName.
final
-
targetKeyFields
→ List<
String> -
Target-side primary key fields used in the join table.
final
- targetModel → ModelDefinition
-
Target-side model definition.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited