ResolvedDatasourceConfig class
Resolved datasource settings used by runtime adapters and CLIs.
Constructors
- ResolvedDatasourceConfig({required String name, required String provider, required String url})
-
Creates a resolved datasource config.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Selected datasource block name.
final
- provider → String
-
Datasource provider string.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
Resolved connection string or database path.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited