ResolvedGeneratorConfig class
Resolved generator settings used by code generation commands.
Constructors
- ResolvedGeneratorConfig({required String name, required String provider, required String outputPath, required bool wasDeclared})
-
Creates a resolved generator config.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Selected generator block name.
final
- outputPath → String
-
Absolute output path for the generated client.
final
- provider → String
-
Generator provider string.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wasDeclared → bool
-
Whether the generator came from an explicit schema block.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited