AggregateQuery class
Backend-neutral aggregate query.
- Annotations
-
- @immutable
Constructors
-
AggregateQuery({required String model, List<
QueryPredicate> where = const <QueryPredicate>[], List<QueryOrderBy> orderBy = const <QueryOrderBy>[], int? skip, int? take, QueryCountSelection count = const QueryCountSelection(), Set<String> avg = const <String>{}, Set<String> sum = const <String>{}, Set<String> min = const <String>{}, Set<String> max = const <String>{}}) -
Creates an aggregate query.
const
Properties
-
avg
→ Set<
String> -
Numeric fields to average.
final
- count → QueryCountSelection
-
Count selections to compute.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
max
→ Set<
String> -
Fields to maximize.
final
-
min
→ Set<
String> -
Fields to minimize.
final
- model → String
-
Model name to query.
final
-
orderBy
→ List<
QueryOrderBy> -
Ordering clauses used before applying skip and take.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skip → int?
-
Number of matching rows to skip before aggregating.
final
-
sum
→ Set<
String> -
Numeric fields to sum.
final
- take → int?
-
Maximum number of rows to aggregate.
final
-
where
→ List<
QueryPredicate> -
Predicates combined by the adapter.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited