DatabaseMiddlewareResult class
Result passed to DatabaseMiddleware.afterQuery.
Constructors
- DatabaseMiddlewareResult({required DatabaseMiddlewareContext context, required Duration duration, Object? result, Object? error, StackTrace? stackTrace})
-
Creates a middleware result.
const
Properties
- context → DatabaseMiddlewareContext
-
Context used for the intercepted operation.
final
- duration → Duration
-
Time spent executing the wrapped operation.
final
- error → Object?
-
Error thrown by the operation, if any.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
Whether the operation completed without throwing.
no setter
- result → Object?
-
Operation result when execution succeeded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace captured for error, if any.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited