QueryRelation class
Relation metadata used for includes, filters, and nested writes.
- Annotations
-
- @immutable
Constructors
-
QueryRelation({required String field, required String targetModel, required QueryRelationCardinality cardinality, required String localKeyField, required String targetKeyField, List<
String> localKeyFields = const <String>[], List<String> targetKeyFields = const <String>[], QueryRelationStorageKind storageKind = QueryRelationStorageKind.direct, String? sourceModel, String? inverseField}) -
Creates relation metadata.
const
Properties
- cardinality → QueryRelationCardinality
-
Relation cardinality.
final
- field → String
-
Source model relation field name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inverseField → String?
-
Optional inverse relation field on the target model.
final
- localKeyField → String
-
Source-side key field used to join records.
final
-
localKeyFields
→ List<
String> -
Source-side key fields used to join records.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceModel → String?
-
Optional source model name when the relation is materialized externally.
final
- storageKind → QueryRelationStorageKind
-
Storage strategy for the relation.
final
- targetKeyField → String
-
Target-side key field used to join records.
final
-
targetKeyFields
→ List<
String> -
Target-side key fields used to join records.
no setter
- targetModel → String
-
Target model name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited