RollbackResult class
Result of rolling back relational migration state.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rolledBack → bool
-
Whether rollback statements were applied.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statementCount → int
-
Number of executed rollback statements.
final
- targetMigrationName → String
-
Name of the migration that was rolled back to.
final
-
warnings
→ List<
String> -
Warnings raised for the rollback plan.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited