MigrationStatus<TIssue extends MigrationStatusIssue> class
Summary returned by relational migration status checks.
Constructors
-
MigrationStatus({required int localMigrationCount, required int activeMigrationCount, required List<
TIssue> issues}) -
Creates a migration status summary.
const
Properties
- activeMigrationCount → int
-
Number of migrations currently active in database history.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClean → bool
-
Whether the local artifacts and database history are in sync.
no setter
-
issues
→ List<
TIssue> -
Status issues discovered during reconciliation.
final
- localMigrationCount → int
-
Number of local migration directories found on disk.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited