ResolveResult class
Result of marking migration history manually.
Constructors
- ResolveResult({required String migrationName, required String action, required bool changed})
-
Creates a resolve result.
const
Properties
- action → String
-
Human-readable action, such as
appliedorrolled back.final - changed → bool
-
Whether history state changed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- migrationName → String
-
Migration name that was resolved.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited